
if [ -x /usr/bin/update-desktop-database ]; then
  /usr/bin/update-desktop-database /usr/share/applications >/dev/null 2>&1
fi

( cd usr/lib ; rm -rf libplasmacomicprovidercore.so.1 )
( cd usr/lib ; ln -sf libplasmacomicprovidercore.so.1.0.0 libplasmacomicprovidercore.so.1 )
( cd usr/lib ; rm -rf libplasmaweather.so.4 )
( cd usr/lib ; ln -sf libplasmaweather.so.4.5.0 libplasmaweather.so.4 )
( cd usr/lib ; rm -rf libkimpanelruntime.so )
( cd usr/lib ; ln -sf libkimpanelruntime.so.0 libkimpanelruntime.so )
( cd usr/lib ; rm -rf libplasmaweather.so )
( cd usr/lib ; ln -sf libplasmaweather.so.4 libplasmaweather.so )
( cd usr/lib ; rm -rf liblancelot-datamodels.so )
( cd usr/lib ; ln -sf liblancelot-datamodels.so.0 liblancelot-datamodels.so )
( cd usr/lib ; rm -rf liblancelot-datamodels.so.0 )
( cd usr/lib ; ln -sf liblancelot-datamodels.so.1.7.0 liblancelot-datamodels.so.0 )
( cd usr/lib ; rm -rf liblancelot.so.1 )
( cd usr/lib ; ln -sf liblancelot.so.1.9.0 liblancelot.so.1 )
( cd usr/lib ; rm -rf liblancelot.so )
( cd usr/lib ; ln -sf liblancelot.so.1 liblancelot.so )
( cd usr/lib ; rm -rf librtm.so.4 )
( cd usr/lib ; ln -sf librtm.so.4.5.0 librtm.so.4 )
( cd usr/lib ; rm -rf libplasmapotdprovidercore.so.1 )
( cd usr/lib ; ln -sf libplasmapotdprovidercore.so.1.0.0 libplasmapotdprovidercore.so.1 )
( cd usr/lib ; rm -rf libplasmacomicprovidercore.so )
( cd usr/lib ; ln -sf libplasmacomicprovidercore.so.1 libplasmacomicprovidercore.so )
( cd usr/lib ; rm -rf libplasmapotdprovidercore.so )
( cd usr/lib ; ln -sf libplasmapotdprovidercore.so.1 libplasmapotdprovidercore.so )
( cd usr/lib ; rm -rf librtm.so )
( cd usr/lib ; ln -sf librtm.so.4 librtm.so )
